package cn.com.infosec.asn1.crmf;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.GeneralName;

public class CertId extends ASN1Encodable {
   private GeneralName issuer;
   private DERInteger serialNumber;

   private CertId(ASN1Sequence seq) {
      this.issuer = GeneralName.getInstance(seq.getObjectAt(0));
      this.serialNumber = DERInteger.getInstance(seq.getObjectAt(1));
   }

   public static CertId getInstance(Object o) {
      if (o instanceof CertId) {
         return (CertId)o;
      } else if (o instanceof ASN1Sequence) {
         return new CertId((ASN1Sequence)o);
      } else {
         throw new IllegalArgumentException("Invalid object: " + o.getClass().getName());
      }
   }

   public static CertId getInstance(ASN1TaggedObject obj, boolean isExplicit) {
      return getInstance(ASN1Sequence.getInstance(obj, isExplicit));
   }

   public GeneralName getIssuer() {
      return this.issuer;
   }

   public DERInteger getSerialNumber() {
      return this.serialNumber;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.issuer);
      var10000.add(this.serialNumber);
      return new DERSequence(var1);
   }
}
